# Webapp3
This module allows people to convert their old webapp2 classes to make them work with python3 using Flask.

You must import flask to be able to use this module.

Here is a quick YouTube video demonstrating how to use this module https://youtu.be/_zWU9e2V8WQ
